@@ -417,14 +417,12 @@ public class PredefMacros {
     }
 
     public static final Atom mbox_macro(final TeXParser tp, final String[] args) throws ParseException {
-        String str = args[1].replaceAll("_", "\\\\_");
-        Atom group = new RomanAtom(new TeXFormula(tp, str, "mathnormal", false, false).root);
+        Atom group = new RomanAtom(new TeXFormula(tp, args[1], "mathnormal", false, false).root);
         return new StyleAtom(TeXConstants.STYLE_TEXT, group);
     }
 
     public static final Atom text_macro(final TeXParser tp, final String[] args) throws ParseException {
-        String str = args[1].replaceAll("_", "\\\\_");
-        return new RomanAtom(new TeXFormula(tp, str, "mathnormal", false, false).root);
+        return new RomanAtom(new TeXFormula(tp, args[1], "mathnormal", false, false).root);
     }
 
     public static final Atom underscore_macro(final TeXParser tp, final String[] args) throws ParseException {
@@ -710,16 +708,24 @@ public class PredefMacros {
     }
 
     public static final Atom cr_macro(final TeXParser tp, final String[] args) throws ParseException {
-        if (!tp.isArrayMode())
-            throw new ParseException("The token \\cr is only available in array mode !");
-        tp.addRow();
+        if (tp.isArrayMode()) {
+            tp.addRow();
+        } else {
+            ArrayOfAtoms array = new ArrayOfAtoms();
+            array.add(tp.formula.root);
+            array.addRow();
+            TeXParser parser = new TeXParser(tp.getIsPartial(), tp.getStringFromCurrentPos(), array, false);
+            parser.parse();
+            array.checkDimensions();
+            tp.finish();
+            tp.formula.root = new MatrixAtom(tp.getIsPartial(), array, MatrixAtom.ARRAY, TeXConstants.ALIGN_LEFT);
+        }
+
         return null;
     }
 
     public static final Atom backslashcr_macro(final TeXParser tp, final String[] args) throws ParseException {
-        if (tp.isArrayMode())
-            tp.addRow();
-        return null;
+        return cr_macro(tp, args);
     }
 
     public static final Atom intertext_macro(final TeXParser tp, final String[] args) throws ParseException {
@@ -888,16 +894,18 @@ public class PredefMacros {
     public static final Atom newcommand_macro(final TeXParser tp, final String[] args) throws ParseException {
         String newcom = args[1];
         Integer nbArgs;
-        if (!tp.isValidName(newcom))
+        if (!tp.isValidName(newcom)) {
             throw new ParseException("Invalid name for the command :" + newcom);
+        }
 
         if (args[3] == null)
             nbArgs = new Integer(0);
         else
             nbArgs = Integer.parseInt(args[3]);
 
-        if (nbArgs == null)
+        if (nbArgs == null) {
             throw new ParseException("The optional argument should be an integer !");
+        }
 
         if (args[4] == null)
             NewCommandMacro.addNewCommand(newcom.substring(1), args[2], nbArgs.intValue());
@@ -910,8 +918,9 @@ public class PredefMacros {
     public static final Atom renewcommand_macro(final TeXParser tp, final String[] args) throws ParseException {
         String newcom = args[1];
         Integer nbArgs;
-        if (!tp.isValidName(newcom))
+        if (!tp.isValidName(newcom)) {
             throw new ParseException("Invalid name for the command :" + newcom);
+        }
 
         if (args[3] == null)
             nbArgs = new Integer(0);
