@@ -39,7 +39,7 @@ import java.util.Set;
  */
 public class TeXParser {
 
-    public TeXFormula formula;
+    TeXFormula formula;
 
     private StringBuffer parseString;
     private int pos;
@@ -322,6 +322,10 @@ public class TeXParser {
         return arrayMode;
     }
 
+    public void setArrayMode(boolean arrayMode) {
+        this.arrayMode = arrayMode;
+    }
+
     /** Return a boolean indicating if the parser must ignore white spaces
      */
     public boolean isIgnoreWhiteSpace() {
@@ -349,6 +353,14 @@ public class TeXParser {
         return pos;
     }
 
+    public String getStringFromCurrentPos() {
+        return parseString.substring(pos);
+    }
+
+    public void finish() {
+        pos = parseString.length();
+    }
+
     /** Add a new row when the parser is in array mode
      * @throws ParseException if the parser is not in array mode
      */
@@ -374,7 +386,13 @@ public class TeXParser {
                     if ("newcommand".equals(com) || "renewcommand".equals(com)) {
                         args = getOptsArgs(2, 2);
                         mac = MacroInfo.Commands.get(com);
-                        mac.invoke(this, args);
+                        try {
+                            mac.invoke(this, args);
+                        } catch (ParseException e) {
+                            if (!isPartial) {
+                                throw e;
+                            }
+                        }
                         parseString.delete(spos, pos);
                         len = parseString.length();
                         pos = spos;
@@ -682,9 +700,16 @@ public class TeXParser {
                         throw new ParseException("Found a closing '" + R_GROUP + "' without an opening '" + L_GROUP + "'!");
                     return;
                 case SUPER_SCRIPT :
-                case SUB_SCRIPT :
                     formula.add(getScripts(ch));
                     break;
+                case SUB_SCRIPT :
+                    if (ignoreWhiteSpace) {
+                        formula.add(getScripts(ch));
+                    } else {
+                        formula.add(new UnderscoreAtom());
+                        pos++;
+                    }
+                    break;
                 case '&' :
                     if (!arrayMode)
                         throw new ParseException("Character '&' is only available in array mode !");
@@ -826,7 +851,7 @@ public class TeXParser {
                     group++;
                 else if (ch == close)
                     group--;
-                else if (ch == ESCAPE)
+                else if (ch == ESCAPE && pos != len - 1)
                     pos++;
             }
 
@@ -1332,6 +1357,10 @@ public class TeXParser {
      * @return the validity of the name
      */
     public boolean isValidName(String com) {
+        if (com == null || "".equals(com)) {
+            return false;
+        }
+
         char c = '\0';
         if (com.charAt(0) == '\\') {
             int pos = 1;
